@@ -25,8 +25,9 @@ Examples:
   zacro robot.xacro --tree             # Show link tree structure to stdout
   zacro robot.xacro --tree -o robot.urdf  # Show tree to stdout and save URDF to file
   zacro robot.xacro --no-format        # Disable formatting output
-  zacro robot.xacro --remove-first-joint  # Remove first joints (modular robots)
-  zacro robot.xacro --no-validate --remove-first-joint -o robot.urdf  # All options
+  zacro robot.xacro --remove-root-link     # Remove world link and connecting joint
+  zacro robot.xacro --remove-root-link base_link  # Remove specified root link
+  zacro robot.xacro --no-validate --remove-root-link -o robot.urdf  # All options
         """
     )
 
@@ -36,8 +37,8 @@ Examples:
                         help='Output file (default: stdout)')
     parser.add_argument('--no-format', action='store_true',
                         help='Disable formatting output (formatting is enabled by default)')
-    parser.add_argument('--remove-first-joint', action='store_true',
-                        help='Remove first joint from each macro expansion (for modular robots)')
+    parser.add_argument('--remove-root-link', nargs='?', const='world', metavar='LINK_NAME',
+                        help='Remove specified root link and connecting joint (default: world)')
     parser.add_argument('-v', '--verbosity', type=int, default=1,
                         help='Verbosity level (default: 1)')
     parser.add_argument('--no-validate', action='store_true', default=False,
@@ -85,7 +86,7 @@ Examples:
                 mappings=mappings,
                 verbosity=args.verbosity,
                 format_output=format_output,
-                remove_first_joint=args.remove_first_joint,
+                remove_root_link=args.remove_root_link,
                 validate_urdf=validate,
                 validation_verbose=validation_verbose
             )
@@ -109,7 +110,7 @@ Examples:
                     mappings=mappings,
                     verbosity=args.verbosity,
                     format_output=format_output,
-                    remove_first_joint=args.remove_first_joint,
+                    remove_root_link=args.remove_root_link,
                     validate_urdf=True,
                     validation_verbose=validation_verbose
                 )
@@ -126,7 +127,7 @@ Examples:
                     mappings=mappings,
                     verbosity=args.verbosity,
                     format_output=format_output,
-                    remove_first_joint=args.remove_first_joint,
+                    remove_root_link=args.remove_root_link,
                     validate_urdf=True,
                     validation_verbose=validation_verbose
                 )
@@ -141,7 +142,7 @@ Examples:
                     mappings=mappings,
                     verbosity=args.verbosity,
                     format_output=format_output,
-                    remove_first_joint=args.remove_first_joint,
+                    remove_root_link=args.remove_root_link,
                     validate_urdf=False
                 )
                 if args.verbosity > 0:
@@ -154,7 +155,7 @@ Examples:
                     mappings=mappings,
                     verbosity=args.verbosity,
                     format_output=format_output,
-                    remove_first_joint=args.remove_first_joint,
+                    remove_root_link=args.remove_root_link,
                     validate_urdf=False
                 )
                 print(result)
