@@ -1,6 +1,6 @@
 use crate::error::{Result, XacroError};
+use crate::xml_element::{Element, XMLNode};
 use std::path::Path;
-use xmltree::{Element, XMLNode};
 
 pub fn parse_file(filename: &Path) -> Result<Element> {
     let content = std::fs::read_to_string(filename).map_err(XacroError::Io)?;
@@ -10,7 +10,6 @@ pub fn parse_file(filename: &Path) -> Result<Element> {
 
 pub fn parse_string(xml_content: &str) -> Result<Element> {
     Element::parse(xml_content.as_bytes())
-        .map_err(|e| XacroError::Parse(format!("XML parsing error: {e}")))
 }
 
 pub fn element_to_string(element: &Element) -> String {
@@ -48,7 +47,6 @@ fn element_to_string_with_ordering(element: &Element) -> String {
                 XMLNode::Comment(comment) => {
                     result.push_str(&format!("<!--{comment}-->"));
                 }
-                _ => {} // Handle other node types if needed
             }
         }
 
