@@ -30,8 +30,8 @@ impl PyXacroProcessor {
         self.processor.set_format_output(format);
     }
 
-    fn set_remove_first_joint(&mut self, remove: bool) {
-        self.processor.set_remove_first_joint(remove);
+    fn set_remove_root_link(&mut self, link_name: Option<String>) {
+        self.processor.set_remove_root_link(link_name);
     }
 
     fn set_validate_urdf(&mut self, validate: bool) {
@@ -104,13 +104,13 @@ fn xacro_to_string(
     mappings: Option<&PyDict>,
     verbosity: Option<u8>,
     format_output: Option<bool>,
-    remove_first_joint: Option<bool>,
+    remove_root_link: Option<&str>,
     validate_urdf: Option<bool>,
     validation_verbose: Option<bool>,
 ) -> PyResult<String> {
     let mut processor = XacroProcessor::new(verbosity.unwrap_or(1));
     processor.set_format_output(format_output.unwrap_or(true)); // Format output by default
-    processor.set_remove_first_joint(remove_first_joint.unwrap_or(false));
+    processor.set_remove_root_link(remove_root_link.map(|s| s.to_string()));
     processor.set_validate_urdf(validate_urdf.unwrap_or(true)); // Validation enabled by default
     processor.set_validation_verbose(validation_verbose.unwrap_or(true));
 
@@ -153,13 +153,13 @@ fn xacro_from_string(
     mappings: Option<&PyDict>,
     verbosity: Option<u8>,
     format_output: Option<bool>,
-    remove_first_joint: Option<bool>,
+    remove_root_link: Option<&str>,
     validate_urdf: Option<bool>,
     validation_verbose: Option<bool>,
 ) -> PyResult<String> {
     let mut processor = XacroProcessor::new(verbosity.unwrap_or(1));
     processor.set_format_output(format_output.unwrap_or(true)); // Format output by default
-    processor.set_remove_first_joint(remove_first_joint.unwrap_or(false));
+    processor.set_remove_root_link(remove_root_link.map(|s| s.to_string()));
     processor.set_validate_urdf(validate_urdf.unwrap_or(true)); // Validation enabled by default
     processor.set_validation_verbose(validation_verbose.unwrap_or(true));
 
@@ -189,7 +189,7 @@ fn xacro_to_file(
     mappings: Option<&PyDict>,
     verbosity: Option<u8>,
     format_output: Option<bool>,
-    remove_first_joint: Option<bool>,
+    remove_root_link: Option<&str>,
     validate_urdf: Option<bool>,
     validation_verbose: Option<bool>,
 ) -> PyResult<()> {
@@ -198,7 +198,7 @@ fn xacro_to_file(
         mappings,
         verbosity,
         format_output,
-        remove_first_joint,
+        remove_root_link,
         validate_urdf,
         validation_verbose,
     )?;
