@@ -91,27 +91,64 @@ pub fn search_up(start_dir: &std::path::Path, relative_path: &str) -> Option<std
     None
 }
 
-/// Resolve a ROS package path, searching up directories if ROS_PACKAGE_PATH is not available
+/// Resolve a ROS2 package path using AMENT_PREFIX_PATH
+fn resolve_ros2_package_path(package_name: &str) -> Option<std::path::PathBuf> {
+    if let Ok(ament_prefix_path) = std::env::var("AMENT_PREFIX_PATH") {
+        let path_separator = if cfg!(windows) { ';' } else { ':' };
+        for prefix_str in ament_prefix_path.split(path_separator) {
+            let prefix_path = std::path::Path::new(prefix_str);
+            let resource_path = prefix_path
+                .join("share")
+                .join("ament_index")
+                .join("resource_index")
+                .join("packages")
+                .join(package_name);
+
+            if resource_path.exists() {
+                // The actual package is located at <prefix>/share/<package_name>
+                let package_path = prefix_path.join("share").join(package_name);
+                if package_path.is_dir() {
+                    return Some(package_path);
+                }
+            }
+        }
+    }
+    None
+}
+
+/// Resolve a ROS package path, searching ROS2 first, then ROS1, then up directories
 pub fn resolve_package_path(
     package_name: &str,
     base_path: &std::path::Path,
 ) -> Option<std::path::PathBuf> {
-    // First try ROS_PACKAGE_PATH if it exists
+    // 1. Try ROS2 (ament) method first
+    if let Some(path) = resolve_ros2_package_path(package_name) {
+        return Some(path);
+    }
+
+    // 2. Try ROS1 (rospack) method if ROS2 fails
     if let Ok(ros_package_path) = std::env::var("ROS_PACKAGE_PATH") {
-        for path_str in ros_package_path.split(':') {
+        // Use the correct path separator for the current OS
+        let path_separator = if cfg!(windows) { ';' } else { ':' };
+        for path_str in ros_package_path.split(path_separator) {
             let path = std::path::Path::new(path_str);
 
             // Check if this path IS the package directory
-            if path.file_name().is_some_and(|name| name == package_name)
-                && path.join("package.xml").exists()
-            {
-                return Some(path.to_path_buf());
+            if path.file_name().is_some_and(|name| name == package_name) && path.exists() {
+                // Prefer package.xml if available, but accept directory existence
+                if path.join("package.xml").exists() || path.is_dir() {
+                    return Some(path.to_path_buf());
+                }
             }
 
             // Check if package exists directly in this path
             let direct_package_path = path.join(package_name);
-            if direct_package_path.exists() && direct_package_path.join("package.xml").exists() {
-                return Some(direct_package_path);
+            if direct_package_path.exists() {
+                // Prefer package.xml if available, but accept directory existence
+                if direct_package_path.join("package.xml").exists() || direct_package_path.is_dir()
+                {
+                    return Some(direct_package_path);
+                }
             }
 
             // Also check if this path contains the package as a subdirectory
@@ -119,10 +156,13 @@ pub fn resolve_package_path(
                 for entry in entries.flatten() {
                     if entry.file_type().is_ok_and(|t| t.is_dir()) {
                         let subdir_package_path = entry.path().join(package_name);
-                        if subdir_package_path.exists()
-                            && subdir_package_path.join("package.xml").exists()
-                        {
-                            return Some(subdir_package_path);
+                        if subdir_package_path.exists() {
+                            // Prefer package.xml if available, but accept directory existence
+                            if subdir_package_path.join("package.xml").exists()
+                                || subdir_package_path.is_dir()
+                            {
+                                return Some(subdir_package_path);
+                            }
                         }
                     }
                 }
@@ -130,7 +170,8 @@ pub fn resolve_package_path(
         }
     }
 
-    // If ROS_PACKAGE_PATH doesn't work, search up from base_path
+    // 3. Fallback to searching up the directory tree
+    // If neither ROS2 nor ROS1 methods work, search up from base_path
     // First, check if we're already inside the package directory
     let mut current_path = base_path.to_path_buf();
 
